@@ -3,6 +3,7 @@ from environs import Env
 from app.basedir import BASE_DIR
 import sentry_sdk
 from sentry_sdk.integrations.django import DjangoIntegration
+from garpix_notify.settings import *  # noqa
 
 
 env = Env()
@@ -49,7 +50,7 @@ INSTALLED_APPS = [
     'social_django',
     # garpixcms
     'garpix_utils',
-    'garpix_qa',
+    'eqator',
     'garpix_page',
     'garpix_menu',
     'garpix_notify',
